@@ -1,5 +1,3 @@
-# encoding:utf-8
-
 """
     DwLoadServer - A DWLOAD server written in Python
     ================================================
@@ -10,18 +8,15 @@
 """
 
 # http://sourceforge.net/p/drivewireserver/wiki/DriveWire_Specification/
+OP_NOP = 0x00
 OP_NAMEOBJ_MOUNT = 0x01
 OP_NAMEOBJ_CREATE = 0x02
 OP_READ_EXTENDED = 0xd2
 OP_WRITE = 0x57
 
-CODE2NAME = dict( # A little hackish?
-    [
-        (v, "%s $%02x" % (k,v))
-        for k,v in locals().copy().items()
-        if k.startswith("OP")
-    ]
-)
+CODE2NAME = {  # A little hackish?
+    v: f"{k} ${v:02x}" for k, v in locals().copy().items() if k.startswith("OP")
+}
 
 if __name__ == '__main__':
-    print(CODE2NAME)
\ No newline at end of file
+    print(CODE2NAME)
