@@ -1,5 +1,3 @@
-# encoding:utf-8
-
 """
     DwLoadServer - A DWLOAD server written in Python
     ================================================
@@ -23,7 +21,7 @@ from dwload_server.utils.file_tools import backup_rename, rename_with_backup, fn
 log = logging.getLogger(__name__)
 
 
-class SaveFilenames(object):
+class SaveFilenames:
     def __init__(self, filepath):
         self.basefilepath = os.path.splitext(filepath)[0]
         self.dwl_filepath = self.basefilepath + ".DWL"
@@ -63,7 +61,7 @@ def save_ascii_post_write_hook(server, filepath, lsn):
     with open(filepath, "rb") as f:
         content = f.read()
 
-    log_hexlines(content, msg="%s data:" % os.path.basename(filepath), level=logging.DEBUG)
+    log_hexlines(content, msg=f"{os.path.basename(filepath)} data:", level=logging.DEBUG)
 
     if not content.endswith(b"\x00\x00\x00"):
         log.info("File ends not with $00 $00 $00, ok.")
